@@ -1,7 +1,7 @@
 package GIS::Distance;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Class::Measure::Length qw( length );
 use Carp qw( croak );
@@ -59,7 +59,10 @@ sub distance {
 
     croak 'Four arguments must be passed to distance()' if @_!=4;
 
-    return length( $self->distance_km(@_), 'km' );
+    return length(
+        $self->{code}->( @_, @{$self->{args}} ),
+        'km',
+    );
 }
 
 sub distance_km {
@@ -70,6 +73,11 @@ sub distance_km {
     return $self->{code}->( @_, @{$self->{args}} );
 }
 
+sub distance_metal {
+    my $self = shift;
+    return $self->{code}->( @_ );
+}
+
 1;
 __END__
 
@@ -112,11 +120,20 @@ then install it and the ::Fast formulas will be automatically used by this modul
 Returns a L<Class::Measure::Length> object for the distance between the
 two degree lats/lons.
 
-See L</distance_km> to return raw kilometers instead.
+See L</distance_km> and L</distance_metal> to return raw kilometers instead.
 
 =head2 distance_km
 
-This works just like L</distance> but returns a raw kilometer measurement.
+This works just like L</distance>, but returns a raw kilometer measurement,
+and is faster when benchmarked over millions of iterations.
+
+=head2 distance_metal
+
+This works just like L</distance_km>, but does no argument checking and ignores
+any formula L</args>.  Calling this gets you pretty close to the fastest bare
+metal speed you can get.  Again, like with L</distance_km>, the speed
+improvements of calling this is noticeable over millions of iterations only
+and you've got to decide if its worth the safety and features you are dropping.
 
 =head1 ATTRIBUTES
 
@@ -154,11 +171,30 @@ their respective documentation.
 
 Returns the fully qualified module name that L</formula> resolved to.
 
+=head1 SPEED
+
+Not that this module is slow, but if you're doing millions of distance
+calculations you may find that adjusting your code a bit may make it
+faster.  Here are some options.
+
+Install L<GIS::Distance::Fast>.
+
+Use L</distance_km> or L</distance_metal> instead of L</distance>.
+
+Call the undocumented C<distance()> function that each formula module
+has.  For example you could bypass this module entirely and just do:
+
+    use GIS::Distance::Fast::Haversine;
+    my $km = GIS::Distance::Fast::Haversine::distance( @coords );
+
+The above would be the ultimate speed demon (as shown in benchmarking)
+but throws away some flexibility and adds some foot-gun support.
+
 =head1 COORDINATES
 
-When passing latitudinal and longitudinal coordinates to L</distance> and
-L</distance_km> they must always be in decimal degree format.  Here is some
-sample code for converting from other formats to decimal:
+When passing latitudinal and longitudinal coordinates to L</distance>
+they must always be in decimal degree format.  Here is some sample code
+for converting from other formats to decimal:
 
     # DMS to Decimal
     my $decimal = $degrees + ($minutes/60) + ($seconds/3600);
@@ -185,9 +221,17 @@ L<GIS::Distance::Polar>
 
 L<GIS::Distance::Vincenty>
 
-These distributions are availabe separately:
+These formulas are available on CPAN:
 
-L<GID::Distance::Fast>
+L<GIS::Distance::Fast::Cosine>
+
+L<GIS::Distance::Fast::GreatCircle>
+
+L<GIS::Distance::Fast::Haversine>
+
+L<GIS::Distance::Fast::Polar>
+
+L<GIS::Distance::Fast::Vincenty>
 
 L<GIS::Distance::GeoEllipsoid>
 
@@ -198,8 +242,9 @@ to have less dependencies.  Since then GIS::Distance itself has become
 tremendously lighter dep-wise, and is still maintained, I suggest you not
 use GIS::Distance::Lite.
 
-L<Geo::Distance> and L<Geo::Distance::XS> have long been deprecated in favor
-of using this module.
+L<Geo::Distance> has long been deprecated in favor of using this module.
+
+L<Geo::Distance::XS> used to be used by L<Geo::Distance> but no longer does.
 
 L<Geo::Inverse> seems to do some distance calculation using L<Geo::Ellipsoid>
 but if you look at the source code it clearly states that the entire meat of
@@ -218,6 +263,7 @@ L<Geo::Distance::Google> looks pretty neat.
 Create a GIS::Coord class that represents a geographic coordinate.  Then modify
 this module to accept input as either lat/lon pairs, or as GIS::Coord objects.
 This would make coordinate conversion as described in L</COORDINATES> automatic.
+Maybe use L<Geo::Point>.
 
 =item *
 
@@ -233,6 +279,10 @@ at L<http://en.wikipedia.org/wiki/Geoid>.
 Make L<GIS::Distance::Google> (or some such name) and wrap it around
 L<Geo::Distance::Google> (most likely).
 
+=item *
+
+Figure out why L<GIS::Distance::Polar> has issues.
+
 =back
 
 =head1 SUPPORT
